@@ -1,4 +1,5 @@
 """Place objects."""
+import numpy as np
 from typing import List
 import matplotlib.axes
 
@@ -17,14 +18,14 @@ class BoundingBox:
         [30, -30, 10, 30]
     """
 
-    def __init__(self, lon: List[float], lat: List[float], desc: str = "NONE") -> None:
+    def __init__(self, lon: List[float], lat: List[float], desc: str = "No Description Given.") -> None:
         """
         Create BBOX.
 
         Args:
             lon (List[float]): Longitude bounds. Degrees East.
             lat (List[float]): Latitude bounds. Degrees North.
-            desc (str): Description of boundary box for debugging. Defaults to "None".
+            desc (str): Description of boundary box for debugging. Defaults to "No Description Given.".
         """
         assert len(lon) == 2
         assert len(lat) == 2
@@ -36,11 +37,13 @@ class BoundingBox:
         """
         Representation string.
         """
-        return str([
-            ("Latitude bounds", self.lat, "degrees_north"),
-            ("Longitude bounds", self.lon, "degrees_east"),
-            self.desc,
-        ])
+        return str(
+            [
+                ("Latitude bounds", self.lat, "degrees_north"),
+                ("Longitude bounds", self.lon, "degrees_east"),
+                self.desc,
+            ]
+        )
 
     def cartopy(self) -> List[float]:
         """
@@ -70,6 +73,7 @@ class BoundingBox:
         ax.set_xlim(self.lon)
         ax.set_ylim(self.lat)
 
+
     def ax_label(self, ax: matplotlib.axes.Axes) -> None:
         """
         Apply BoundingBox as labels to your graph.
@@ -80,18 +84,64 @@ class BoundingBox:
         ax.set_xlabel(self.lon)
         ax.set_ylabel(self.lat)
 
+    def pad(self, buffer: float = 1) -> "BoundingBox":
+        """
+        Pad the BoundingBox by some number of degrees.
+
+        Args:
+            buffer (float, optional): How many degrees East and North
+                to go out from existing buffer. Defaults to 1.
+
+        Returns:
+            BoundingBox: A bounding box that is padded by the buffer.
+        """
+        return BoundingBox([self.lon[0] - buffer, self.lon[1] + buffer], 
+                            [self.lat[0] - buffer, self.lat[1] + buffer], 
+                            desc=self.desc + " padded by " + str(buffer) + " degrees")
+
+    def indices_inside(self, lons: np.ndarray, lats: np.ndarray) -> np.ndarray:
+        """
+        Get indices of points inside the bounding box.
+
+        Args:
+            lons (np.ndarray): Longitudes of points to check.
+            lats (np.ndarray): Latitudes of points to check.
+
+        Returns:
+            np.ndarray: Indices of points inside the bounding box.
+        """
+        return np.where(
+            (lons >= self.lon[0])
+            & (lons <= self.lon[1])
+            & (lats >= self.lat[0])
+            & (lats <= self.lat[1]))
+
 
 class Point:
-    def __init__(self, lon: float, lat: float) -> None:
+    def __init__(self, lon: float, lat: float, desc: str = "No Description Given.") -> None:
         """
         Initialise point.
 
         Args:
-            lon (float): Longitude.
-            lat (float): Latitude.
+            lon (float): Longitude. Degrees East.
+            lat (float): Latitude. Degrees North.
+            desc (str): description. Defaults to "No Description Given.".
         """
         self.lon = lon
         self.lat = lat
+        self.desc = desc
+
+    def __repr__(self) -> str:
+        """
+        Representation string.
+        """
+        return str(
+            [
+                ("Latitude", self.lat, "degrees_north"),
+                ("Longitude", self.lon, "degrees_east"),
+                self.desc,
+            ]
+        )
 
     def bbox(self, buffer: float = 3) -> BoundingBox:
         """
@@ -119,4 +169,5 @@ class Point:
         return BoundingBox(
             [self.lon - buffer, self.lon + buffer],
             [self.lat - buffer, self.lat + buffer],
+            desc="Bounding Box around point: " + self.desc,
         )
